@@ -1,5 +1,6 @@
 import os
 from typer import Typer
+from pathlib import Path
 from kamaqi.utils.files import read_project_file
 
 app = Typer(help="Run your project")
@@ -13,13 +14,15 @@ def run_project():
 
     if project_file["project_type"] == "normal":
         
-        if os.name=="posix":
-            os.system("source env/bin/activate")
-
-        if os.name=="nt":
-            os.system(f".\env\Scripts\\activate")
-
-        os.system("uvicorn main:app --reload")
+        env_path: Path
+        
+        if os.name == "posix":
+            env_path = Path("env/bin/activate").resolve()
+            os.system(f". {str(env_path)} && uvicorn main:app --reload")
+        
+        if os.name == "nt":
+            env_path = Path("env/Scripts/activate").resolve()
+            os.system(f"{str(env_path)} && uvicorn main:app --reload")
 
     if  project_file["project_type"] == "docker":
         os.system(f"docker-compose up -d && docker-compose logs -f {project_name}")
